**Example 1: 更新参数模板**



Input: 

```
tccli tsf UpdateConfigTemplate --cli-unfold-argument  \
    --ConfigTemplateId xxx \
    --ConfigTemplateName xxx \
    --ConfigTemplateType xxx \
    --ConfigTemplateValue xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "!2vko3112424d2322",
        "Result": true
    }
}
```

